# COPYRIGHT (c) 2020-2022 Pietro Mandracci

# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.

# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.

# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

""" PYthon tools for SImulation and CAlculus: tools for data analysis

    This sub-package contains some modules which can be helpful to manage 
    various types of data, 
    such as spectra, distribution functions, data histograms

    Modules
    -------

    *univariate*
        analysis of univariate data 
    *bivariate*
        analysis of bivariate data               
    *spectra*
        manage a set of bivariate data sets and make 
        some calculations on them
"""

